import { CartLoadingSkeleton } from "@/components/common/loading-skeleton/cart-loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import Cart from "@/components/sections/cart/cart";
import CartPageClient from "@/components/sections/cart/cart-page-client";
import Invoice from "@/components/sections/cart/invoice";
import OrderStatus from "@/components/sections/cart/order-status";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { fetchCart } from "@/servers/actions/cart-action";
import { HydrationBoundary, dehydrate } from "@tanstack/react-query";
import { Suspense } from "react";

export default async function Page(props: any) {
	const { params, searchParams } = props;
	const { locale } = await params;
	const order_id = searchParams.UserField1 as string | undefined;

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/cart",
			label: {
				en: "Shopping cart",
				ar: "سلة المشتريات",
			},
		},
	];

	const cartTabs = [
		{
			label: {
				en: "Shopping Cart",
				ar: "سلة المشتريات",
			},
			content: <Cart />,
		},
		{
			label: {
				en: "Invoice",
				ar: "الفاتورة",
			},
			content: <Invoice />
		},
	];

	// Only add the third tab if order_id exists in the URL
	if (order_id) {
		cartTabs.push({
			label: {
				en: "Confirm Purchase",
				ar: "تأكيد الشراء",
			},
			content: (
				<div className="text-center py-8">
					<OrderStatus />
				</div>
			),
		});
	}

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({ queryKey: ["cart"], queryFn: fetchCart }),
	]);

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<main className="block overflow-hidden text-gray-700">
				<Header />
				<Suspense fallback={<CartLoadingSkeleton locale={locale} />}>
					<PageBreadcrump
						backgroundUrl={"/heros/cart.png"}
						locale={locale}
						subtitle={{
							en: "Bin Taleb Company",
							ar: "شركة بن طالب",
						}}
						title={{
							en: "Shopping cart",
							ar: "سلة المشتريات",
						}}
						breadcrumbItems={breadcrumbItems}
					/>

					<CartPageClient locale={locale} cartTabs={cartTabs} />

					<Footer />
				</Suspense>
			</main>
		</HydrationBoundary>
	);
}
